@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = "3.004";
+our $VERSION = "3.005";
 # ABSTRACT: time tracking for impatient and lazy command line lovers
 
 use App::TimeTracker::Data::Task;
@@ -307,12 +307,149 @@ App::TimeTracker - time tracking for impatient and lazy command line lovers
 
 =head1 VERSION
 
-version 3.004
+version 3.005
 
 =head1 SYNOPSIS
 
 Backend for the C<tracker> command. See L<tracker> and/or C<perldoc tracker> for details.
 
+=head1 INSTALLATION
+
+L<App::TimeTracker> is a L<Perl|http://perl.org> application, and thus requires
+a recent Perl (>= 5.10). It also reuses a lot of code from
+L<CPAN|http://cpan.org>.
+
+=head2 From CPAN
+
+The easiest way to install the current stable version of L<App::TimeTracker> is
+via L<CPAN|http://cpan.org>. There are several different CPAN clients
+available:
+
+=head3 cpanminus
+
+  ~$ cpanm App::TimeTracker
+  --> Working on App::TimeTracker
+  Fetching http://search.cpan.org/CPAN/authors/id/D/DO/DOMM/App-TimeTracker-2.009.tar.gz ... OK
+  Configuring App-TimeTracker-2.009 ... OK
+  Building and testing App-TimeTracker-2.009 ... OK
+  Successfully installed App-TimeTracker-2.009
+  1 distribution installed
+
+If you don't have C<cpanminus> installed yet, L<install it right
+now|http://search.cpan.org/dist/App-cpanminus/lib/App/cpanminus.pm#INSTALLATION>:
+
+  ~$ curl -L http://cpanmin.us | perl - --sudo App::cpanminus
+
+=head3 CPAN.pm
+
+CPAN.pm is available on ancient Perls, and feels a bit ancient, too.
+
+  cpan App::TimeTracker
+
+=head2 From a tarball
+
+To install L<App::TimeTracker> from a tarball, do the usual CPAN module
+install dance:
+
+  ~/perl/App-TimeTracker$ perl Build.PL
+  ~/perl/App-TimeTracker$ ./Build
+  ~/perl/App-TimeTracker$ ./Build test
+  ~/perl/App-TimeTracker$ ./Build install  # might require sudo
+
+=head2 From a git checkout
+
+Clone the repository if you have not already done so, and enter the
+C<App-TimeTracker> directory:
+
+  ~$ git clone git@github.com:domm/App-TimeTracker.git
+  ~$ cd App-TimeTracker
+
+C<App-TimeTracker> uses L<Dist::Zilla> to build, test and install the code,
+hence this must be installed first, e.g. with C<cpanm>:
+
+  ~/path/to/App-Tracker$ cpanm Dist::Zilla
+
+Now install the distribution's dependencies, test and install in the usual
+manner for C<Dist::Zilla> projects:
+
+  ~/path/to/App-Tracker$ dzil listdeps --missing | cpanm
+  ~/path/to/App-Tracker$ dzil test
+  ~/path/to/App-Tracker$ dzil install
+
+=head1 PLUGINS
+
+Custom commands or adaptations to your workflow can be implemented via
+an "interesting" set of L<Moose>-powered plugins. You can configure
+different sets of plugins for different jobs or projects.
+
+B<Tip:> Use C<tracker plugins> to list all installed plugins. Read more
+about each plugin in C<App::TimeTracker::Command::PLUGIN-NAME>.
+
+=head2 Note about (missing) Plugins
+
+Up to version 2.028 a lot of plugins where included in the main distribution
+C<App-TimeTracker>. To make installation easier and faster, all non-core
+command plugins have been moved into distinct, standalone distributions.
+
+The following plugins are affected:
+
+=over
+
+=item * App::TimeTracker::Git (which also includes SyncViaGit)
+
+=item * App::TimeTracker::RT
+
+=item * App::TimeTracker::TellRemote (which was called Post2IRC earlier)
+
+=item * App::TimeTracker::Overtime has been removed, while the idea is nice, the API and implementation are not good enough.
+
+=item * App::TimeTracker::TextNotify has been removed.
+
+=back
+
+=head1 SOURCE CODE
+
+=head2 git
+
+We use C<< git >> for version control and maintain a public repository on
+L<github|http://github.com>.
+
+You can find the latest version of L<App::TimeTracker> here:
+
+L<https://github.com/domm/App-TimeTracker>
+
+If you want to work on L<App::TimeTracker>, add a feature, add a plugin or fix
+a bug, please feel free to L<fork|http://help.github.com/fork-a-repo/> the
+repo and send us L<pull requests|http://help.github.com/send-pull-requests/>
+to merge your changes.
+
+To report a bug, please B<do not> use the C<< issues >> feature from github;
+use RT instead.
+
+=head2 CPAN
+
+L<App::TimeTracker> is distributed via L<CPAN|http://cpan.org/>, the
+Comprehensive Perl Archive Network. Here are a few different views of
+CPAN, offering slightly different features:
+
+=over
+
+=item * L<https://metacpan.org/release/App-TimeTracker/>
+
+=item * L<http://search.cpan.org/dist/App-TimeTracker/>
+
+=back
+
+=head1 Viewing and reporting Bugs
+
+We use L<rt.cpan.org|http://rt.cpan.org> (thank you
+L<BestPractical|http://rt.bestpractical.com>) for bug reporting. Please do
+not use the C<issues> feature of github! We pay no attention to those...
+
+Please use this URL to view and report bugs:
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-TimeTracker>
+
 =head1 CONTRIBUTORS
 
 Maros Kollar, Klaus Ita, Yanick Champoux, Lukas Rampa, David Schmidt, Michael Kröll, Thomas Sibley, Nelo Onyiah, Jozef Kutej, Roland Lammel, Ruslan Zakirov, Kartik Thakore, Tokuhiro Matsuno, Paul Cochrane, David Provost, Mohammad S Anwar, Håkon Hægland
